import { AgentxService, Service } from "@agentx/agentx-services";
import { createJsApiLogger } from "./common/_logger";
import { ServiceChecker } from "./common/_service-shecker";
declare type LatestInfoData = {
    agentName?: string;
    teamId?: string;
    teamName?: string;
    dn?: string;
    status?: string;
    subStatus?: string;
    idleCodes?: Service.Aqm.Configs.Entity[];
    wrapupCodes?: Service.Aqm.Configs.Entity[];
    outDialRegex?: string;
    isOutboundEnabledForTenant?: boolean;
    isOutboundEnabledForAgent?: boolean;
};
declare type Listeners = {
    updated: (p: {
        name: keyof LatestInfoData;
        value?: string;
        oldValue?: string;
    }[]) => void;
};
declare type Events = keyof Listeners;
export declare class AgentStateInfoJsapi {
    private readonly emitter;
    private readonly logger;
    private SERVICE?;
    private readonly serviceChecker;
    private checkService;
    private listeners;
    private emit;
    private update;
    private static getOutdialRegex;
    constructor(config: {
        logger: ReturnType<typeof createJsApiLogger>;
        serviceChecker: ServiceChecker;
    });
    latestData: LatestInfoData;
    init(SERVICE?: AgentxService): Promise<void>;
    cleanup(): void;
    private fetchLatestData;
    private subscribeSelfDataEvents;
    private unsubscribeSelfDataEvents;
    stateChange(stateData: {
        state: "Available" | "Idle";
        auxCodeIdArray: string;
    }): Promise<import("@agentx/agentx-services/dist/types/core/aqm-reqs").Msg<{
        eventType: "AgentDesktopMessage";
        agentId: string;
        trackingId: string;
        auxCodeId: string;
        agentSessionId: string;
        orgId: string;
        status: string;
        subStatus: "Available" | "Idle";
        lastIdleCodeChangeTimestamp: number;
        lastStateChangeTimestamp: number;
        type: "AgentStateChangeSuccess";
    }> | undefined>;
    fetchAddressBooks(): Promise<Service.Aqm.Agent.AddressBooks | undefined>;
    addEventListener<T extends Events>(eventName: T, listener: Listeners[T]): void;
    removeEventListener<T extends Events>(eventName: T, listener: Listeners[T]): void;
    removeAllEventListeners(): void;
}
export declare const createAgentStateInfoJsApi: () => AgentStateInfoJsapi;
export {};
